# `fuzzy-set`

[![PyPI](https://img.shields.io/pypi/v/fuzzy-set-nokia.svg)](https://pypi.python.org/pypi/fuzzy-set-nokia/)
[![Build](https://github.com/Nokia-Bell-Labs/fuzzy-set/workflows/build/badge.svg)](https://github.com/Nokia-Bell-Labs/fuzzy-set/actions/workflows/build.yml)
[![Documentation](https://github.com/Nokia-Bell-Labs/fuzzy-set/workflows/docs/badge.svg)](https://github.com/Nokia-Bell-Labs/fuzzy-set/actions/workflows/docs.yml)
[![ReadTheDocs](https://readthedocs.org/projects/fuzzy-set/badge/?version=latest)](https://fuzzy-set.readthedocs.io/en/)


## Overview

The `fuzzy-set` package provides a [Python3](https://www.python.org/downloads/) framework built on top of [Numpy](https://numpy.org/) and [Matplotlib](https://matplotlib.org/) allowing to manipulate and plot:

* [Fuzzy Sets](https://fuzzy-set.readthedocs.io/en/latest/fuzzy_set.fuzzy_set.html)
* [Fuzzy Numbers](https://fuzzy-set.readthedocs.io/en/latest/fuzzy_set.fuzzy_number.html)
* [Trapezoidal Fuzzy Numbers](https://fuzzy-set.readthedocs.io/en/latest/fuzzy_set.fuzzy_set.html)

## [Documentation](https://fuzzy-set.readthedocs.io/en/latest/)

* [Installation](https://fuzzy-set.readthedocs.io/en/latest/installation.html)
* [API](https://fuzzy-set.readthedocs.io/en/latest/api/index.html)
* [Authors](https://fuzzy-set.readthedocs.io/en/latest/authors.html)
* [History](https://fuzzy-set.readthedocs.io/en/latest/history.html)

## References

* [Wikipedia: Fuzzy set](https://en.wikipedia.org/wiki/Fuzzy_set) 
* [Managing Uncertainties in ICT Services Life Cycle Assessment using Fuzzy Logic](https://hal.science/hal-04532041/), Édouard Guégain, Thibault Simon, Alban Rahier, Romain Rouvoy
* [Environmental life cycle assessment with support of fuzzy-sets](https://link.springer.com/article/10.1007/BF02977589), Albert Weckenmann & Achim Schwan
* [Ecologits Github](https://github.com/genai-impact/ecologits/tree/main/ecologits/data)
